#!/bin/bash

if [ -f /sys/kernel/security/kysec/status ];then
	kstatus=`cat /sys/kernel/security/kysec/status`
	if [ $kstatus -eq 2 ];then
		echo "2" > /etc/kysec/kysec_s
		if [ `echo $?` -ne 0 ];then
			echo "kysec的状态记录失败"
			echo "2" > /etc/kysec/kysec_s
		else
			echo "4" > /sys/kernel/security/kysec/status
			if [ `echo $?` -ne 0 ];then
				echo "kysec设置软模式失败"
				echo "4" > /sys/kernel/security/kysec/status
			fi
		fi
	fi
fi

if [ -f  /sys/kernel/security/kysec/iptables ];then
	iptable_status=`cat /sys/kernel/security/kysec/iptables`
	if [ $iptable_status -eq 1 ];then
		echo "1" > /etc/kysec/iptable_s
		if [ `echo $?` -ne 0 ];then
			echo "防火墙的状态记录失败"
			echo "1" > /etc/kysec/iptable_s
		else
			echo "0" > /sys/kernel/security/kysec/iptables
			if [ `echo $?` -ne 0 ];then
				echo "iptable状态设置失败"
				echo "0" > /sys/kernel/security/kysec/iptables
			fi
		fi
	fi
fi

if [ -f  /sys/kernel/security/kysec/ppro ];then
	ppro_status=`cat /sys/kernel/security/kysec/ppro`
	if [ $ppro_status -eq 1 ];then
		echo "1" > /etc/kysec/ppro_s
		if [ `echo $?` -ne 0 ];then
			echo "进程保护的状态记录失败"
			echo "1" > /etc/kysec/ppro_s
		else
			echo "0" > /sys/kernel/security/kysec/ppro
			if [ `echo $?` -ne 0 ];then
				echo "进程保护的状态设置失败"
				echo "0" > /sys/kernel/security/kysec/ppro
			fi
		fi
	fi
fi

# 检查root密码是否过期
current_date=$(date +'%Y%m%d')
expire_date_str=$(LC_ALL="C" chage -l root | grep 'Password expires' | cut -d':' -f 2)
# 过滤未设置密码过期时间的情况
if ! [[ "${expire_date_str}" =~ .*never.* ]];then
	expire_date=$(date -d "${expire_date_str}" +"%Y%m%d")
	if [ "${current_date}" -gt "${expire_date}" ];then
		# 已过期
		chage -M -1 root
	fi
fi

# kid状态设置(需求#32575,默认关闭kid)
# 升级前,若当前系统下的libsecurity-conf包大于等于1.1.0.1-0k3.2版本,则不修改kid状态(1.集成该版本以后的系统默认kid为0, 2.可能用户手动开启了kid,保留用户设置的状态)
libsecurity_pkg_version=$(dpkg -s libsecurity-conf|grep "Version" |awk '{print $2}')
kysec_conf="/etc/kysec/kysec.conf"
if [ -n "${libsecurity_pkg_version}" ];then
	if dpkg --compare-versions "${libsecurity_pkg_version}" lt "1.1.0.1-0k3.2";then
		sed -i 's/kysec_kid =.*/kysec_kid = 0/' "$kysec_conf"
	fi
fi

# 定义状态文件（标记预处理是否完成）
STATUS_FILE="/var/lib/softwarectrl_prepared.status"

# 异常处理：中断时清理状态
trap 'cleanup' EXIT INT TERM
cleanup() {
  [ -f "$STATUS_FILE" ] && rm -f "$STATUS_FILE"
}

# 检查是否已预处理
if [ -f "$STATUS_FILE" ]; then
  echo "预处理已完成，无需重复执行"
  exit 0
fi

# 执行预处理操作
echo "开始升级前准备"
sed -i 's/bw_status="1"/bw_status="0"/g' /etc/dpkg/udeblist.xml
systemctl stop dbus-com.kylin.softwarectrl.service
systemctl disable dbus-com.kylin.softwarectrl.service
mv /usr/share/dbus-1/system-service/com.kylin.softwarectrl.service \
   /usr/share/dbus-1/system-service/com.kylin.softwarectrl.service.bak

# 标记预处理完成（需升级后脚本主动清除）
touch "$STATUS_FILE"
echo "预处理完成，状态文件已创建：$STATUS_FILE"